<a id="mypy-boto3-dax"></a>

# mypy-boto3-dax

[![PyPI - mypy-boto3-dax](https://img.shields.io/pypi/v/mypy-boto3-dax.svg?color=blue)](https://pypi.org/project/mypy-boto3-dax)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-dax.svg?color=blue)](https://pypi.org/project/mypy-boto3-dax)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-dax?color=blue)](https://pypistats.org/packages/mypy-boto3-dax)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.DAX 1.18.57](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/dax.html#DAX)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 5.5.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-dax docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dax/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-dax](#mypy-boto3-dax)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

Install `boto3-stubs` for `DAX` service.

```bash
python -m pip install boto3-stubs[dax]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[dax]` in your environment:
  `python -m pip install 'boto3-stubs[dax]'`

Both type checking and auto-complete should work for `DAX` service. No explicit
type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto-stubs[dax]` in your environment:
  `python -m pip install 'boto3-stubs[dax]'`

Both type checking and auto-complete should work for `DAX` service. No explicit
type annotations required, write your `boto3` code as usual. Auto-complete can
be slow on big projects or if you have a lot of installed `boto3-stubs`
submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[dax]` in your environment:
  `python -m pip install 'boto3-stubs[dax]'`
- Run `mypy` as usual

Type checking should work for `DAX` service. No explicit type annotations
required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[dax]` in your environment:
  `python -m pip install 'boto3-stubs[dax]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `DAX` service. No explicit type annotations
required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`DAXClient` provides annotations for `boto3.client("dax")`.

```python
import boto3

from mypy_boto3_dax import DAXClient

client: DAXClient = boto3.client("dax")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: DAXClient = session.client("dax")
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_dax.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_dax import DAXClient
from mypy_boto3_dax.paginator import (
    DescribeClustersPaginator,
    DescribeDefaultParametersPaginator,
    DescribeEventsPaginator,
    DescribeParameterGroupsPaginator,
    DescribeParametersPaginator,
    DescribeSubnetGroupsPaginator,
    ListTagsPaginator,
)

client: DAXClient = boto3.client("dax")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
describe_clusters_paginator: DescribeClustersPaginator = client.get_paginator("describe_clusters")
describe_default_parameters_paginator: DescribeDefaultParametersPaginator = client.get_paginator("describe_default_parameters")
describe_events_paginator: DescribeEventsPaginator = client.get_paginator("describe_events")
describe_parameter_groups_paginator: DescribeParameterGroupsPaginator = client.get_paginator("describe_parameter_groups")
describe_parameters_paginator: DescribeParametersPaginator = client.get_paginator("describe_parameters")
describe_subnet_groups_paginator: DescribeSubnetGroupsPaginator = client.get_paginator("describe_subnet_groups")
list_tags_paginator: ListTagsPaginator = client.get_paginator("list_tags")
```

<a id="literals"></a>

### Literals

`mypy_boto3_dax.literals` module contains literals extracted from shapes that
can be used in user code for type checking.

```python
from mypy_boto3_dax.literals import (
    ChangeTypeType,
    ClusterEndpointEncryptionTypeType,
    DescribeClustersPaginatorName,
    DescribeDefaultParametersPaginatorName,
    DescribeEventsPaginatorName,
    DescribeParameterGroupsPaginatorName,
    DescribeParametersPaginatorName,
    DescribeSubnetGroupsPaginatorName,
    IsModifiableType,
    ListTagsPaginatorName,
    ParameterTypeType,
    SSEStatusType,
    SourceTypeType,
    ServiceName,
    PaginatorName,
)

def check_value(value: ChangeTypeType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_dax.type_defs` module contains structures and shapes assembled to
typed dictionaries for additional type checking.

```python
from mypy_boto3_dax.type_defs import (
    ClusterTypeDef,
    CreateClusterRequestRequestTypeDef,
    CreateClusterResponseTypeDef,
    CreateParameterGroupRequestRequestTypeDef,
    CreateParameterGroupResponseTypeDef,
    CreateSubnetGroupRequestRequestTypeDef,
    CreateSubnetGroupResponseTypeDef,
    DecreaseReplicationFactorRequestRequestTypeDef,
    DecreaseReplicationFactorResponseTypeDef,
    DeleteClusterRequestRequestTypeDef,
    DeleteClusterResponseTypeDef,
    DeleteParameterGroupRequestRequestTypeDef,
    DeleteParameterGroupResponseTypeDef,
    DeleteSubnetGroupRequestRequestTypeDef,
    DeleteSubnetGroupResponseTypeDef,
    DescribeClustersRequestRequestTypeDef,
    DescribeClustersResponseTypeDef,
    DescribeDefaultParametersRequestRequestTypeDef,
    DescribeDefaultParametersResponseTypeDef,
    DescribeEventsRequestRequestTypeDef,
    DescribeEventsResponseTypeDef,
    DescribeParameterGroupsRequestRequestTypeDef,
    DescribeParameterGroupsResponseTypeDef,
    DescribeParametersRequestRequestTypeDef,
    DescribeParametersResponseTypeDef,
    DescribeSubnetGroupsRequestRequestTypeDef,
    DescribeSubnetGroupsResponseTypeDef,
    EndpointTypeDef,
    EventTypeDef,
    IncreaseReplicationFactorRequestRequestTypeDef,
    IncreaseReplicationFactorResponseTypeDef,
    ListTagsRequestRequestTypeDef,
    ListTagsResponseTypeDef,
    NodeTypeDef,
    NodeTypeSpecificValueTypeDef,
    NotificationConfigurationTypeDef,
    PaginatorConfigTypeDef,
    ParameterGroupStatusTypeDef,
    ParameterGroupTypeDef,
    ParameterNameValueTypeDef,
    ParameterTypeDef,
    RebootNodeRequestRequestTypeDef,
    RebootNodeResponseTypeDef,
    ResponseMetadataTypeDef,
    SSEDescriptionTypeDef,
    SSESpecificationTypeDef,
    SecurityGroupMembershipTypeDef,
    SubnetGroupTypeDef,
    SubnetTypeDef,
    TagResourceRequestRequestTypeDef,
    TagResourceResponseTypeDef,
    TagTypeDef,
    UntagResourceRequestRequestTypeDef,
    UntagResourceResponseTypeDef,
    UpdateClusterRequestRequestTypeDef,
    UpdateClusterResponseTypeDef,
    UpdateParameterGroupRequestRequestTypeDef,
    UpdateParameterGroupResponseTypeDef,
    UpdateSubnetGroupRequestRequestTypeDef,
    UpdateSubnetGroupResponseTypeDef,
)

def get_structure() -> ClusterTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-dax` version is the same as related `boto3` version and follows
[PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-dax docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dax/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
